;=============================================================================
; DWGSCALE.lsp    Set drawing scale via dialog (command function for AutoCAD)
; (c) Copyright 2001 TimeSavers for CAD
; from: www.timesaversforcad.com
;-----------------------------------------------------------------------------
; Description:
;
; Function for setting Drawing Scale Factor via dialog box.
;
; Sets DIMSCALE variable to real number based on industry standard
; scale factors for Architectural, Engineering and Decimal scales.
; Sets LTSCALE to half the returned scale factor (can change below).
;
; Calls DWGSCALE.DCL dialog control file.  DWGSCALE.DCL must be placed
; in a directory listed under AutoCAD's support seach path.
;=======================================================================
(defun c:dwgscale (/ *dsf:err* scl:f get:scl dsfid dsf ltsd)

  (setq ltsd 2.0) ;;<<- divider for LTSCALE

  ;-ERROR HANDLING
  (defun *dscl:err* (m)
    (or (member m '("Funkce zruena" "_quit / _exit _abort" "console break"))
        (prompt (strcat "\n< " m " >\n"))
    )
    (setq *error* *e*)(princ)
  )

  ;-CONFIRM SCALE FACTOR [dialog: button - edit_box / ok_cancel]
  (defun scl:f (/ sf s)
    (while (and (setq s (cond (s)((getvar "dimscale")))
                      s (cond ((get:scl))(s))
                )
                (setq s (fix s))
                (new_dialog "sclf" dsfid)
                (set_tile "e" (itoa s))
                (action_tile "accept" "(setq sf (atoi (get_tile \"e\")))(done_dialog 1)")
                (action_tile "b" "(done_dialog 2)")
                (= (start_dialog) 2)
           )
    )
    sf
  )

  ;-DRAWING SCALE [dialog: scale buttons / ok_cancel]
  (defun get:scl (/ sf es ed)
    (if (new_dialog "getscl" dsfid)
      (progn
        (mode_tile (itoa (fix s)) 2)
        (foreach k '("384""192""128""96""64""48""32""24""16""12""8""4""1"
                     "6000""2400""1200""720""600""480""360""240""120""60.0""12.0""1.0"
                     "500""200""100""60""50""40""30""20""10""5""1.00")
          (action_tile k "(setq sf (atoi $key))(done_dialog)")
        )
        (action_tile "VO" "(setq es T)(done_dialog)")
        (start_dialog)
      )
    )
    (if es
      (while (or (initget " ")
                 (progn
                   (setq es (entsel "\nNastaven mtka kreslen <vyberte objekt>: "))
                   (cond ((not es)(princ "0 nalezeno"))
                         ((= es "") nil)
                         ((= (cdr (assoc 0 (setq ed (entget (car es))))) "INSERT")
                           (setq sf (cdr (assoc 41 ed))) nil
                         )
                         ((princ "*Neplatn vbr*"))
                   )
                 )
             )
      )
    )
    sf
  )

  ;-GET VALUES
  (setq *e* (cond (*e*)(*error*))
        *error* *dscl:err*
  )

  ;-ACTUAL FUNCTION
  (and (if (minusp (setq dsfid (load_dialog "dwgscale")))
         (prompt "\nNelze nalzt DWGSCALE.DCL. Tento soubor mus bt umstn ve sloce podporovanch soubor AutoCADu.")
         T
       )
       (setq dsf (scl:f))
       (setvar "dimscale" dsf)
       (setvar "ltscale" (/ dsf ltsd))	;;<<- divider for LTSCALE
  )
  (if dsfid (unload_dialog dsfid))
  (setq *error* *e*)
  (princ)
)
;-END FILE
