;;; -----------------------------------------------------------------
;;; (c) Franz Ploetzl Ottensheim/Donau/Austria
;;; franz@ploetzl.at http://www.ploetzl.at/tools
;;; A-4100 Ottensheim Holzweg 5 tel +43 (0)732 771250 16 fax 12
;;; A-1050 Wien Hartmanngassse 13/4/36 tel +43 (0)1     5456702
;;; -----------------------------------------------------------------
;;; Englische Dialoge
;;; Robert Kuklovszky, 1060 Wien
;;; -----------------------------------------------------------------
;;; PROFIL.LSP dieses file
;;; PROFIL.DCL dcl dialog
;;; PROFIL.DAT dat file --> profile def.datei
;;; PROFIL.INI ini file --> benutzereinstellungen
;;; PROFIL.??? def file --> def. der einzelen profile
;;; PROFIL.GER deutscher DIALOG
;;; PROFIL.ENG english DIALOG
;;;
;;; rel12/13/0.1 1095pf 
;;; rel12/13/14/1.0 0897 pf
;;; 		option einfuegepunkt
;;;		hohlprofile
;;;		scharffur mit solids mglich
;;;             deutscher/englischer dialog
;;; rel12/13/14/15/1.1 1100 pf
;;;             HQU, HRE
;;;
;;; -----------------------------------------------------------------
;;; platformen getestet:
;;; winnt rel14,win2000 rel15
;;; -----------------------------------------------------------------
;;
;;   Erstellt Stahlbau Profile basierend auf der 17. Auflage der
;;   'Stahlbau-Profile', herausgeben vom Verein Deutscher 
;;   Eisenhuettenleute 1989. 
;;
;;   Folgende Erzeugungsmoeglichkeiten stehen zu Verfuegung:
;;   'Linien'      - das Profil wird aus einzelen Liniensegmente erzeugt
;;   'Polylinie'   - das Profil wird als Polyline erzeugt  
;;   'Festkoerper' - das Profil wird als Festkoerper oder Region erzeugt
;;                   die Kombination Festkoerper und grob ist nicht moeglich  
;;  
;;   Die Einstellung Einheiten ist fuer die rchtige Groesse des Profils
;;   verantwortlich. Hier sollte die verwendete ZeichenEinheit gewaehlt werden.
;;               
;;   Folgende Darstellungsmoeglickeiten stehen zur Verfuegung:
;;     'exakt'       - exakte Kontur
;;   'vereinfacht' - ohne Ausrundungen und
;;     'grob'      - nur die aeussersten Abmessungen
;; 
;;   Folgende Optionen koennen gewaehlt werden:
;;     'Schwerpunkt' - stellt den Schw.pkt des als Punkt dar
;;     'Schubmi.pkt' - stellt den Schubmittelpunkt als Punkt dar
;;     'Schraffur'   - schraffiert das Profil
;;     'Block'       - erzeugt aus dem Profil einen Block
;;                     der Blockname setzt sich aus der Profilbezeichnung
;;                     (HEA) und seiner Kenngroesse (300) zusammen (HEA300)
;;     'Laenge'      - Laenge des Profils in Z-Richtung
;;     'Winkel'      - Winkel um dir Z-Achse
;; 
;;   Folgende Schraffureinstellungen koennen vorgenommen werden:
;;     'Muster'      - Schraffurmuster 
;;     'Faktor'      - Schraffurfaktor 
;; 
;;   In der Datei PROFIL.INI koennen Grundeinstellungen geaendert werden
;;     Einheit, Objekterzeugung, Darstellung, Layer, Orientierung,
;;     Schraffureinstellungen.  
;; 
;;   Die Datei PROFIL.DAT stellt die referenz zu den einzelen
;;   ProfildefinitionsDateien PROFIL.??? her. 
;;   Folgende ProfilDateien stehen zur Verfuegung:
;;     PROFIL.IPE I-PE          Mittelbreites I-Profil
;;     PROFIL.HEB I-PB     HE-B Breites       I-Profil
;;     PROFIL.HEA I-PBl    HE-A Breites       I-Profil leichte Ausfuehrung
;;     PROFIL.HEM I-PBv    HE-M Breites       I-Profil verstaerkte Ausfuehrung
;;     PROFIL.IPS I-PBS         Breites       I-Profil breite Flansche
;;     PROFIL.LGL L-GL          L-Profil gleichschenkelig
;;     PROFIL.LUG L-UGL         L-Profil ungleichschenkelig
;;     PROFIL.__Z Z             Z-Profil
;;     PROFIL.__T T             T-Profil
;;     PROFIL.__U U             U-Profil
;;     PROFIL.HQU HOQU          Hohlprofil quadratisch
;;     PROFIL.HRE HORE          Hohlprofil rechteckig
;;     PROFIL.HRU HORU          Hohlprofil rund
;; 
;;;-----------------------------------------------------------------
;;
;;release
;;
  (setq pr:rel "rel12/13/14/15/1.1 1100 pf")
;;
;;ini file
;;
  (if (not pr:init) ; wenn variablen noch nicht initialisiert
                    ; pr:init in profil.ini def.
    (if (setq file (findfile "profil.ini"))
      (load file)
      (progn (alert (nth 0 pr:txt))(exit))
    )
  )
;;
;; dialogdatei laden
;;
   (cond
      ((= (strcase pr:lang) "GER")(setq dfile "profil.ger"))
      ((= (strcase pr:lang) "ENG")(setq dfile "profil.eng"))
      ('T (setq dfile "profil.ger"))
   )
   (if (setq file (findfile dfile))
     (progn
       (prompt (strcat "\nLade " dfile "."))
       (load dfile)
       (prompt "ok.")
     )
   )
;;------------
;;------------
;; profil main
;;------------
;;------------
(defun c:profil () (c:apf_f:profil))
(defun c:apf_f:profil ()
  
  (prompt (strcat "\nPROFIL                                          " pr:rel))
;;error handling save
  (pr:error_s (list "angdir" "blipmode" "cmdecho" "osmode" "thickness" "clayer"))
;;dat file
  (if (not (setq file (findfile "profil.dat")))
    (progn (alert (nth 1 pr:txt))(exit))
  )
;;dcl dialog
  (apf_f:profil_dcl)
;;if ok
  (if pr:work (apf_f:profil_work pr:profil))
;; error handling restore
  (pr:error_r)
  (princ)

);defun
;;--------------------
;; setup_dcl steuerung
;;--------------------
(defun apf_f:profil_dcl (/ line fr du ldiag done lae char word liste)
;;dcl file
  (if (not (setq lfile (findfile "profil.dcl")))
    (alert (strcat "Kann PROFIL.DCL nicht finden."))
  )
;; init var
  (setq pr:entity  (strcase pr:entity T)
        pr:darst   (strcase pr:darst  T) 
        pr:la_prof (strcase pr:la_prof nil)
        pr:la_achs (strcase pr:la_achs nil)
        pr:la_schr (strcase pr:la_schr nil)
  )
  (if (not pr:laen)
    (setq pr:laen "0.00")
    (if (/= (type pr:laen) 'STR )
      (setq pr:laen (rtos pr:laen))
    )
  )    
  (if (not pr:wink)
    (setq pr:wink "0.00")
    (if (/= (type pr:wink) 'STR )
      (setq pr:wink (rtos pr:wink))
    )
  )    
;solid und grob nicht moeglich
  (if (and (= pr:entity "solid") (= pr:darst "grob"))
    (setq pr:darst "exakt")
  )
;;open dat file 
  (setq fr (open file "r")
        pr:typ_f nil
        pr:typ_t nil
  )
;;read header/liste profil typen
  (repeat 12 (read-line fr))
  (while (setq line (read-line fr))
    (setq pr:typ_f (cons (substr line 1 10) pr:typ_f)
          pr:typ_t (cons (substr line 11) pr:typ_t)
    ) 
  );while
  (close fr)
  (setq pr:typ_f (reverse pr:typ_f)			;liste def dateien 
        pr:typ_t (reverse pr:typ_t)			;liste beschreibung dcl
  )
  (if (not pr:typ_) (setq pr:typ_ "0"))			;nr liste 0=erste element in der liste
;;liste einheiten dcl erstellen
  (setq pr:ei_t nil pr:ei_w nil) 
  (foreach du pr:einh
    (setq pr:ei_t (cons (car du)  pr:ei_t)              ;liste nur bezeichnungen
          pr:ei_w (cons (caddr du) pr:ei_w)   		;liste nur wertepaare
    )
  ) 
  (setq pr:ei_t (reverse pr:ei_t)
        pr:ei_w (reverse pr:ei_w) 
  )
;;liste einfgepunkt dcl erstellen
  (setq pr:efp_t nil pr:efp_w nil) 
  (foreach du pr:efpt
    (setq pr:efp_t (cons (car du)  pr:efp_t)              ;liste nur bezeichnungen
          pr:efp_w (cons (cadr du) pr:efp_w)   		;liste nur wertepaar
    )
  ) 
  (setq pr:efp_t (reverse pr:efp_t)
        pr:efp_w (reverse pr:efp_w) 
  )
  (if (not pr:efp_) (setq pr:efp_ "0"))			;nr liste 0=erste element in der liste
;;
;;dcl dialog start
;;
  (cond
    ((= (strcase pr:lang) "GER") (setq ld "profil_ger"))
    ((= (strcase pr:lang) "ENG") (setq ld "profil_eng"))
    ('T (setq ld "profil_eng"))
  ) 
  (setq ldiag (load_dialog lfile))
  (if ldiag 
    (if (not (new_dialog ld ldiag))(exit))
    (exit)
  );if 
;;popup typ
  (start_list "typ")
    (mapcar 'add_list pr:typ_t)
  (end_list)   
  (set_tile "typ" pr:typ_)
;;popup profile
  (pr_dcl_typ pr:typ_)
;;popup einheiten 
  (start_list "einheit")
    (mapcar 'add_list pr:ei_t)
  (end_list)   
  (if (not pr:ei_)
    (cond
      ((= apf_v:emst 1)     (setq pr:ei_ "0"))
      ((= apf_v:emst 0.01)  (setq pr:ei_ "1"))
      ((= apf_v:emst 0.001) (setq pr:ei_ "2"))
      ('T                   (setq pr:ei_ "0"))
    );cond
  );if
  (set_tile "einheit" pr:ei_)
;;popup einfgepunkt
  (start_list "einfpkt")
    (mapcar 'add_list pr:efp_t)
  (end_list)   
  (set_tile "einfpkt" pr:efp_)
;;entity
  (set_tile "entity" pr:entity)
;;darstellung
  (set_tile "darst" pr:darst)
;;layer
;  (set_tile "laprofilt" (strcase pr:la_prof nil))
;  (set_tile "laachsent" (strcase pr:la_achs nil))
;;laenge/winkel
  (set_tile "laenge" pr:laen)
  (set_tile "winkel" pr:wink)
;;schraffur
  (set_tile "schraffstil" pr:schr_stil)
  (set_tile "schraffmst" pr:schr_mst)
;;optionen
  (set_tile "mpkt"    pr:mpkt)
  (set_tile "spkt"    pr:spkt)
  (set_tile "achsen"  pr:achs)
  (set_tile "schraff" pr:schr)
  (set_tile "block"   pr:blk)
;; slide
  (pr_dcl_dia)
;;action_tile
   (action_tile "einheit"   "(setq pr:ei_    $VALUE)")
   (action_tile "einfpkt"   "(setq pr:efp_    $VALUE)")
   (action_tile "entity"    "(pr_dcl_entity  $VALUE)")
   (action_tile "darst"     "(pr_dcl_darst   $VALUE)")

   (action_tile "mpkt"      "(setq pr:mpkt   $VALUE)")
   (action_tile "spkt"      "(setq pr:spkt   $VALUE)")  
   (action_tile "achsen"    "(setq pr:achs   $VALUE)")
   (action_tile "schraff"   "(pr_dcl_schr    $VALUE)")
   (action_tile "block"     "(setq pr:blk    $VALUE)")

   (action_tile "typ"       "(pr_dcl_typ      $VALUE)")
   (action_tile "profile"   "(setq pr:profil_ $VALUE)")

   (action_tile "winkel"    "(setq pr:wink   $VALUE)")
   (action_tile "laenge"    "(setq pr:laen   $VALUE)")

   (action_tile "schraffstil" "(setq pr:schr_stil   $VALUE)")
   (action_tile "schraffmst" "(setq pr:schr_mst   $VALUE)")

;   (action_tile "laprofilb" "(pr_dcl_lapb)")
;   (action_tile "laprofilt" "(pr_dcl_lapt  $VALUE)")
;   (action_tile "laachsenb" "(pr_dcl_laab)")
;   (action_tile "laachsent" "(pr_dcl_laat  $VALUE)")

   (action_tile "info"    "(pr_dcl_info)")
   (action_tile "help"    "(pr_dcl_help)")  
   (action_tile "chancel" "(done_dialog 0)")
   (action_tile "accept"  "(done_dialog 1)")
   
   (setq done (start_dialog))

   (unload_dialog ldiag)
   (cond
     ((= done 1)
       (setq pr:laen   (atof pr:laen)
             pr:wink   (atof pr:wink)
             pr:ei_t   (strcase (nth (atoi pr:ei_) pr:ei_t) nil);text
             pr:ei_w   (nth (atoi pr:ei_) pr:ei_w)              ;wert
             pr:efp_t   (strcase (nth (atoi pr:efp_) pr:efp_t) nil);text
             pr:efp_w   (nth (atoi pr:efp_) pr:efp_w)              ;wert
             pr:profil (nth (atoi pr:profil_) pr:profil)        ;profil werte    
             word:list nil
             pr:schr_stil (strcase pr:schr_stil)
       ) 
;       (princ pr:ei_t)(princ "\n ") 
;       (princ pr:ei_w)(princ "\n ") 
;       (princ pr:entity)(princ "\n ")
;       (princ pr:mpkt)(princ "\n ")
;       (princ pr:spkt)(princ "\n ") 
;       (princ pr:achs)(princ "\n ") 
;       (princ pr:schr)(princ "\n ") 
;       (princ pr:laen)(princ "\n ") 
;       (princ pr:wink)(princ "\n ") 
;       (princ pr:la_prof)(princ "\n ") 
;       (princ pr:la_achs)(princ "\n ") 
;       (princ pr:profil_)(princ "\n ") 
;       (princ pr:profil)(princ "\n ") 
;;umwandeln der profilwerte /zeile/ in eine liste
       (setq lae (strlen pr:profil) word "" liste nil)
       (repeat (+ lae 1)
         (setq char (substr pr:profil 1 1) 
               pr:profil (substr pr:profil 2)
         ) 
         (if (and (/= char " ")(/= char ""))
           (setq word (strcat word char))
           (if (/= word "")(setq liste (cons word liste) word ""))
         ) 
       );repeat
       (setq pr:profil (reverse liste)
             pr:work T
       )
;       (princ pr:profil)(princ "\n") 
;       (princ pr:work)(princ "\n") 

     );done 1
     ((= done 0) 
       (princ (strcat "\n" (nth 15 pr:txt)))
       (setq pr:work nil)
     );done 0
   );cond

   (princ)

);defun
;;
;;---------------------------------------------------------------------------
;; soubroutines dcl
;;---------------------------------------------------------------------------
;;
;; help profil
;;
(defun pr_dcl_help () 

  (pr_dcl_box pr:dcl_help)

)
;;
;; info profil
;;
(defun pr_dcl_info () 

  (pr_dcl_box pr:dcl_box)

)
;;;
;;; info liste
;;;
;;;
;;; info 
;;;
(defun pr_dcl_box (wert) 
   (setq _dialog (load_dialog "profil"))
   (if _dialog (new_dialog "info" _dialog)
     (progn 
       (alert (strcat "Kann Dialog " _dialog " nicht initialisieren!"))(exit)
     );progn
   );if 
   (set_tile "text1" (strcat "acad_pf - PROFIL.LSP   " pr:rel))
   (set_tile "text2" "")
   (set_tile "text3" (strcat (getvar "platform") " " (getvar "acadver") " "(getvar "_pkser")))
   (set_tile "text4" "(c) Franz Ploetzl, Ottensheim/Linz/Vienna - Austria")
   (set_tile "text5" "franz@ploetzl.at www.ploetzl.at/tools") 
   (setq x (dimx_tile "slidei")
         y (dimy_tile "slidei")
   )
   (start_image "slidei")
   (fill_image 0 0 x y 0) 
   (slide_image 0 0 x y "profil(profil)")
   (end_image)
   (start_list "list") 
   (mapcar (quote add_list) wert) 
   (end_list) 
   (action_tile "accept" "(done_dialog 1)") 
   (start_dialog)
  
)
;;
;;layer editbox profil
;;
(defun pr_dcl_lapt (wert)

  (if (not (tblsearch "LAYER" wert))
    (alert (strcat "Layer " (strcase wert) " wird mit standard Farbe und Linientyp erzeugt."))
  )
  (set_tile "laprofilt" (setq pr:la_prof (strcase wert)))    

)
;;
;;layer button achsen
;;
(defun pr_dcl_laab (/ du)

  (if (setq du (apf_f:listx "L" nil nil))
    (set_tile "laachsent" (setq pr:la_achs du))    
  )

)
;;
;;layer editbox profil
;;
(defun se_dcl_laat (wert)

  (if (not (tblsearch "LAYER" wert))
    (alert (strcat "Layer " (strcase wert) " wird mit standard Farbe und Linientyp erzeugt."))
  )
  (set_tile "laprofilt" (setq pr:la_achs (strcase wert)))    

)
;;
;;dcl profile erstellt liste
;;

(defun pr_dcl_typ (wert / file fr du)

  
;;popup profile
  (setq file (findfile (setq du (nth (atoi wert) pr:typ_f))))
  (if (not file)
    (progn 
      (alert (strcat "APF_FEHLER: Kann " du " nicht finden."))
      (set_tile "typ" pr:typ_)
    )
;;read header/liste profile
    (progn 
      (setq fr (open file "r") pr:profil nil)
      (setq pr:dia (substr du 8 3))
;(princ pr:dia)
      (pr_dcl_dia) 
      (repeat 12 (read-line fr))
      (while (setq line (read-line fr))
        (setq pr:profil (cons line pr:profil)) 
      );while
      (setq pr:profil (reverse pr:profil)			;liste profildaten
            du (- (length pr:profil) 1)
            pr:profil_ (if (not pr:profil_) "0" pr:profil_)	;nr liste 0=erste element in der liste
            pr:profil_ (if (> (atoi pr:profil_) du) (itoa du) pr:profil_)
            pr:typ_ wert
      ) 
      (close fr)
;;popup profile
      (start_list "profile")
        (mapcar 'add_list pr:profil)
      (end_list)   
      (set_tile "profile" pr:profil_)
    );progn
  );if

)
;;
;; dcl profil dia
;;
(defun pr_dcl_dia (/ x y)

  (cond
      ((= pr:darst "exakt")   (setq dux "0"))
      ((= pr:darst "einfach") (setq dux "1"))
      ((= pr:darst "grob")    (setq dux "2"))
      ('T (setq dux "T"))
  )
;(princ dux)
;; slide
  (setq x (dimx_tile "slide")
        y (dimy_tile "slide")
  )
  (start_image "slide")
    (fill_image 0 0 x y 0) 
    (slide_image 0 0 x y (strcat "profil(" pr:dia dux ")" ))
  (end_image)

)  
;;
;; dcl schraff
;;
(defun pr_dcl_schr (wert)
  (if (= pr:darst "grob")
    (set_tile "schraff" (setq pr:schr "0"))
    (setq pr:schr wert)
  )
)
;;
;; dcl darst
;;
(defun pr_dcl_darst (wert)
  (if (and (or (= pr:entity "solid")(= pr:entity "poly")) (= wert "grob"))
    (set_tile "entity" (setq pr:entity "line"))
  ) 
  (setq pr:darst wert)
  (if (= pr:darst "grob")  (set_tile "schraff" (setq pr:schr "0")))
  (pr_dcl_dia)
)  
;;
;; dcl entity
;;
(defun pr_dcl_entity (wert)
  (if (and (= pr:darst "grob") (or (= wert "poly") (= wert "solid")))
    (set_tile "darst" (setq pr:darst "einfach"))
  )
  (setq pr:entity wert)
  (if (= pr:darst "grob")  (set_tile "schraff" (setq pr:schr "0")))
  (pr_dcl_dia)
)  
;;
;; bestimmt scwerpunkt aufgrund der einfuegepunktoptionen 
;; fr sym. querschnitte S=M b,h
;;
(defun pr_einfpkt_sym (opt ho br)

       (cond  
         ((= pr:efp_w "OL")
           (setq pts (polar pts (* 3 pih) (/ ho 2.0))
                 pts (polar pts 0 (/ br 2.0))
           )
         )
         ((= pr:efp_w "ML") (setq pts (polar pts 0 (/ br 2.0)) ) )
         ((= pr:efp_w "UL")
           (setq pts (polar pts pih (/ ho 2.0))
                 pts (polar pts 0   (/ br 2.0))
           )  
         )
         ((= pr:efp_w "OM") (setq pts (polar pts (* 3 pih) (/ ho 2.0)) ) )
         ((= pr:efp_w "UM") (setq pts (polar pts pih (/ ho 2.0)) ) )
         ((= pr:efp_w "OR")
           (setq pts (polar pts (* 3 pih) (/ ho 2.0))
                 pts (polar pts pi  (/ br 2.0))
           ) 
         )
         ((= pr:efp_w "MR") (setq pts (polar pts pi (/ br 2.0)) ) )
         ((= pr:efp_w "UR")
           (setq pts (polar pts pih (/ ho 2.0))
                 pts (polar pts pi   (/ br 2.0))
           )
         )
         ((= pr:efp_w "SM") (setq pts pts) )
         ((= pr:efp_w "SW") (setq pts pts) )
         ('T (alert "UNGEULTIGE OPTION EINFUEGEPUNKT:\nSchwerpunkt wird als Voorgabe verwendet.") )

       );cond

)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; work
;;
(defun apf_f:profil_work (wert 
 ;                         / pih ho br ts tg tt r1 r2 r3 hc h-2c ey ez aa bb
 ;                           ym b1 alph pt1 pt2 pt3 pt4 pt5 pt6 pt7 pt8 pt9 pt10
 ;                           pt11 pt12 pt13 pt14 pt15 pt16 pt17 pt18 pt19 pt20
 ;                           pt21 pt01 pt0 pts ptm pta1 pta2 pta3 pta4 pts1 pts2
 ;                           ptr1 ptr2 ptr3 ptr4 pt_1 pt_2 ptt1 ptt2 ptt3 ptt4  lastobj1
 ;                          ; typ typ3 
                         )

  (if (/= pr:wink 0.0)(command "_.ucs" "_z" pr:wink))
  (command "_.layer" "_ma" pr:la_prof "")
  (setq typ (strcase (substr (setq typt (car wert)) 1 1))
        typ3 (strcase (substr (setq typt (car wert)) 1 3)) ;hohlprofile
        pih (/ pi 2.0) 
  )
;;setzen des letzten elementes fuer den auswahlsatz
  (setq entity-list (entlast))
;;schwerpunkt zeigen
  (while (not (setq pts (getpoint (strcat "\n" (nth 14 pr:txt) pr:efp_t ": ")))))

;(princ pr:efp_w)

;;set var
  (setvar "angdir"   0)
  (setvar "cmdecho"  0) 
  (setvar "osmode"   0)
  (setvar "blipmode" 0)
  (setvar "thickness" pr:laen)

;;cond profiltypen    
  (cond
;;I-profil
;(IPE240 240 120 6.2 9.8)
    ((or (= typ "I") (= typ3 "HEA"))
       (setq ho (* (atof (nth 1 wert)) pr:ei_w) ;hoehe
             br (* (atof (nth 2 wert)) pr:ei_w)  ;breite
             ts (* (atof (nth 3 wert)) pr:ei_w)  ;stegdicke
             tg (* (atof (nth 4 wert)) pr:ei_w)  ;gurtdicke 
             r1 (* (atof (nth 5 wert)) pr:ei_w)  ;radius 1
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts ho br)

       (setq ptm pts
             pt0  (polar pts 0 (/ ts 2.0))
             h-2c (- ho tg tg r1 r1)
             bf   (- (/ br 2.0) r1 (/ ts 2.0))
             pt1  (polar pt0 (* 3 pih) (/ h-2c 2.0))
             pt2  (polar pt1 pih h-2c)
             pt3  (polar pt2 pih r1)
             pt4  (polar pt3 0   r1)
             pt5  (polar pt4 0   bf)
             pt6  (polar pt5 pih tg)
             pts1 (polar pt6 pi (/ br 2.0))
             pt7  (polar pt6 pi  br)
             pt8  (polar pt7 (* 3 pih) tg)
             pt9  (polar pt8 0 bf)
             pt10 (polar pt9 0 r1)
             pt11 (polar pt10 (* 3 pih) r1)
             pt12 (polar pt11 (* 3 pih) h-2c)
             pt13 (polar pt12 (* 3 pih) r1)
             pt14 (polar pt13 pi r1)
             pt15 (polar pt14 pi bf)
             pt16 (polar pt15 (* 3 pih) tg)
             pts2 (polar pt16 0 (/ br 2.0))
             pt17 (polar pt16 0 br)
             pt18 (polar pt17 pih tg)
             pt19 (polar pt18 pi bf)
             pt20 (polar pt19 pi r1)
             pta1 (polar pts pi (* br 0.6667))
             pta2 (polar pts 0  (* br 0.6667))
             pta3 (polar pts pih (* 0.6667 ho))
             pta4 (polar pts (* 3 pih) (* 0.6667 ho))
       );setq            
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt1 pt2 "_arc" pt4 "_line" pt5 pt6 pt7 pt8 pt9 "_arc" pt11
                              "_line" pt12 "_arc" pt14 "_line" pt15 pt16 pt17 pt18 pt19
                              "_arc" pt1 "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
           (command "_.pline" pt20 pt3 pt5 pt6 pt7 pt8 pt10 pt13 pt15 pt16 pt17 pt18 "_c")      
         );exakt
         ((= pr:darst "grob")
           (command "_.line" pt16 pt17 ""
                    "_.line" pts2 pts1 ""
                    "_.line" pt6  pt7  ""
           )
         );grob
       )
    );I
;;L-profil
; (L35x4 35 35 4 5 2.5)
    ((= typ "L")		
       (setq aa (* (atof (nth 1 wert)) pr:ei_w)  ;hoehe
             bb (* (atof (nth 2 wert)) pr:ei_w)  ;breite
             ts (* (atof (nth 3 wert)) pr:ei_w)  ;stegdicke
             r1 (* (atof (nth 4 wert)) pr:ei_w)  ;radius 1
             r2 (* (atof (nth 5 wert)) pr:ei_w)  ;radius 2
             ey (* (atof (nth 6 wert)) pr:ei_w)  ;ey
             ez (* (atof (nth 7 wert)) pr:ei_w)  ;ez
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts aa bb)
       
       (if (and (/= pr:efp_w "SM") (/= pr:efp_w "SW"))
         (setq pts (polar pts pi (- (/ bb 2.0) ez))
               pts (polar pts (* 3 pih) (- (/ aa 2.0) ey))
         )  
       )

       (setq ptm  pts
             pt0  (polar pts pi ez)
             pt01 (polar pts (* 3 pih) ey)
             pt1 (polar pt0 (* 3 pih) ey)
             pt2 (polar pt1 0 bb)
             pt3 (polar pt2 pih (- ts r2))
             pt4 (polar pt2 pih ts)
             pt5 (polar pt4 pi r2)
             pt6 (polar pt4 pi (- bb r1 ts))
             pt7 (polar pt6 pi r1)
             pt8 (polar pt7 pih r1)
             pt9 (polar pt7 pih (- aa ts r2))
             pt10 (polar pt9 pih r2)
             pt11 (polar pt10 pi r2)
             pt12 (polar pt10 pi ts)
             pta1 (polar pt0 pi (* bb 0.2))
             pta2 (polar pt0 0  (* bb 1.2))
             pta3 (polar pt01 pih (* aa 1.2))
             pta4 (polar pt01 (* 3 pih) (* aa 0.2))
       ) 
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt1 pt2 pt3 "_arc" "_radius" r2 pt5 "_line" pt6 "_arc" pt8
                              "_line" pt9 "_arc" pt11 "_line" pt12 "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
;;;;;;;;
;;;;;;;; BUG
;;;;;;;;
           (command "_.pline" pt1 pt2 pt4 pt7 pt10 pt11 "_close")      
           (alert "VORSICHT: Fehler in der Darstelllung.")
         );exakt
         ((= pr:darst "grob")
           (command "_.pline" pt12 pt1 pt2"")
         );grob
       )
    );L
;;Z-profil
; (Z160 160 70 8.5 11 11 5.5)
    ((= typ "Z")
       (setq ho (* (atof (nth 1 wert)) pr:ei_w)  ;hoehe
             br (* (atof (nth 2 wert)) pr:ei_w)  ;breite
             ts (* (atof (nth 3 wert)) pr:ei_w)  ;stegdicke
             tg (* (atof (nth 4 wert)) pr:ei_w)  ;gurtdicke
             r1 (* (atof (nth 5 wert)) pr:ei_w)  ;radius 1
             r2 (* (atof (nth 6 wert)) pr:ei_w)  ;radius 2
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts ho br)

       (setq ptm  pts
             pt0  (polar pts pi (/ ts 2.0))
             pt1  (polar pt0 (* 3 pih) (/ ho 2.0))
             pt7  (polar pt1 0 (/ ts 2.0))
             pt2  (polar pt1 0 br)
             pt3  (polar pt2 pih (- tg r2))
             pt4  (polar pt2 pih tg)
             pt5  (polar pt4 pi r2)
             pt6  (polar pt4 pi (- br ts r1))
             pt8  (polar pt6 pi r1)
             pt9  (polar pt8 pih r1)
             pt10 (polar pt8 pih (- ho tg))
             pt71 (polar pt10 pi (/ ts 2.0))
             pt11 (polar pt10 pi br)
             pt12 (polar pt11 (* 3 pih) (- tg r2))
             pt13 (polar pt11 (* 3 pih) tg)
             pt14 (polar pt13 0 r2)
             pt15 (polar pt13 0 (- br ts r1))
             pt16 (polar pt15 0 r1)
             pt17 (polar pt16 (* 3 pih) r1)
             pta1 (polar pts pi (* br 1.2))
             pta2 (polar pts 0 (* br 1.2))
             pta3 (polar pts (* 3 pih) (/ (* ho 1.2) 2))
             pta4 (polar pts pih (/ (* ho 1.2) 2))
       )
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt1 pt2 pt3 "_arc" "_radius" r2 pt5 "_line" pt6 "_arc" pt9
                              "_line" pt10 pt11 pt12 "_arc" "_radius" r2 pt14 "_line" pt15 
                              "_arc" pt17 "_line" "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
           (command "_.pline" pt1 pt2 pt4 pt8 pt10 pt11 pt12 pt13 pt16 "_close")      
         );exakt
         ((= pr:darst "grob")
           (command "_.pline" pt11 pt71 pt7 pt2"")
         );grob
       )
    );Z
;;T-profil
;(T70 70 70 8 8 4 2 19.4)
    ((= typ "T")
       (setq ho (* (atof (nth 1 wert)) pr:ei_w)  ;hoehe
             br (* (atof (nth 2 wert)) pr:ei_w)  ;breite
             tt (* (atof (nth 3 wert)) pr:ei_w)  ;steg/gurt/dicke
             r1 (* (atof (nth 3 wert)) pr:ei_w)  ;radius 1
             r2 (* (atof (nth 4 wert)) pr:ei_w)  ;radius 2
             r3 (* (atof (nth 5 wert)) pr:ei_w)  ;radius 3
             hc (* (atof (nth 6 wert)) pr:ei_w)  ;h-c
             ey (* (atof (nth 7 wert)) pr:ei_w)  ;ey
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts ho br)
       (if (and (/= pr:efp_w "SW")(/= pr:efp_w "SM")) (setq pts (polar pts pih (- (/ ho 2.0) ey)) ) )
         
       (setq ptm pts
             pt0  (polar pts pih ey)
             pt1  (polar pt0 (* 3 pih) ho)
             pts0 (polar pt0 (* 3 pih) (/ ho 2.0))
             pts1 (polar pts0 0 (/ tt 2.0))
             pts2 (polar pts0 pi  (/ tt 2.0))
             pthc (polar pt1 pih hc)
             alph (atan (/ 2.0 100)) 			;2% neigung
             pt_1 (polar pts1 (- pi alph) r3)
             pt_2 (polar pt1  pih r3)
             ptr3 (inters pt_1 (polar pt_1 (- pih alph) 1) pt_2 (polar pt_2 0 1) nil)
             pt2  (polar ptr3 (* 3 pih) r3) 
             pt4  (polar ptr3 alph r3)
             pt3  (inters pt1 pt2 pt4 pts1 nil)
             pt5  (inters pt3 pts1 pthc (polar pthc 0 1) nil)              

             pt_1 (polar pts2 alph r3)
             pt_2 (polar pt1  pih r3)
             ptr3 (inters pt_1 (polar pt_1 (+ pih alph) 1) pt_2 (polar pt_2 0 1) nil)
             pt21 (polar ptr3 (* 3 pih) r3) 
             pt19 (polar ptr3 (+ alph pi) r3)
             pt20 (inters pt1 pt21 pt19 pts2 nil)
             pt18 (inters pt20 pts2 pthc (polar pthc 0 1) nil)              

             ptt1 (polar pt0  0  (/ br 4.0)) 
             ptt2 (polar ptt1 (* 3 pih) tt)
             ptt3 (polar pt0  pi (/ br 4.0)) 
             ptt4 (polar ptt3 (* 3 pih) tt)

             pt6  (inters ptt2 (polar ptt2 alph 1) pt3 pt5 nil)
             pt11 (polar pt0 0  (/ br 2.0))
             pt9  (inters pt6 ptt2 pt11 (polar pt11 (* 3 pih) 1) nil)
             ptr1 (polar pt5 (- (* 2 pi) alph) r1)
             pt7  (polar ptr1 (+ pih alph) r1)
             pt_1 (polar ptt2 (+ pih alph) r2)
             pt_2 (polar pt11 pi r2)
             ptr2 (inters pt_1 (polar pt_1 alph 1) pt_2 (polar pt_2 (* 3 pih) 1) nil)
             pt8  (polar ptr2 (+ (* 3 pih) alph) r2)
             pt10 (polar ptr2 0 r2)

             pt17 (inters ptt4 (polar ptt4 (* alph -1.0) 1) pt20 pt18 nil)
             pt12 (polar pt0 pi  (/ br 2.0))
             pt14 (inters pt17 ptt4 pt12 (polar pt12 (* 3 pih) 1) nil)
             ptr1 (polar pt18 (+ alph pi) r1)
             pt16 (polar ptr1 (- pih alph) r1)
             pt_1 (polar ptt4 (- pih alph) r2)
             pt_2 (polar pt12 0 r2)
             ptr2 (inters pt_1 (polar pt_1 (* alph -1.0) 1) pt_2 (polar pt_2 (* 3 pih) 1) nil)
             pt15 (polar ptr2 (- (* 3 pih) alph) r2)
             pt13 (polar ptr2 pi r2)

             pta1 (polar pts pi  (* 0.6 br))
             pta2 (polar pts 0   (* 0.6 br))
             pta3 (polar pts pih (+ ey (* 0.1 ho)) )
             pta4 (polar pts (* 3 pih) (+ (- ho ey) (* 0.1 ho)) ) 
       );setq
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt2 "_arc" "_radius" r3 pt4 "_line" pt5 "_arc" pt7 "_line" pt8
                              "_arc" pt10 "_line" pt11 pt12 pt13 "_arc" "_radius" r2 pt15 
                              "_line" pt16 "_arc" pt18 "_line" pt19 "_arc" pt21
                              "_line" pt2 "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
           (command "_.pline" pt3 pt6 pt9 pt11 pt12 pt14 pt17 pt20 "_close")
         );exakt
         ((= pr:darst "grob")
           (command "_.line" pt12 pt11 ""
                    "_.line" pt0 pt1 ""
           )
         );grob
       )

    );T
;;U-profil
;(U140 140 60 7 10 10 5 8 17.5)
    ((= typ "U")
       (setq ho   (* (atof (nth  1 wert)) pr:ei_w)  ;hoehe
             br   (* (atof (nth  2 wert)) pr:ei_w)  ;breite
             ts   (* (atof (nth  3 wert)) pr:ei_w)  ;stegdicke
             tg   (* (atof (nth  4 wert)) pr:ei_w)  ;gurtdickeradius 1
             r1   (* (atof (nth  5 wert)) pr:ei_w)  ;radius 1
             r2   (* (atof (nth  6 wert)) pr:ei_w)  ;radius 2
             h-2c (* (atof (nth  7 wert)) pr:ei_w)  ;2h-c
             t1   (* (atof (nth  8 wert)) pr:ei_w)  ;t1
             ez   (* (atof (nth  9 wert)) pr:ei_w)  ;ey
             ym   (* (atof (nth 10 wert)) pr:ei_w)  ;ey
       )
       (if (<= ho 300)
         (setq b1 (/ br 2.0)        alph (atan (/ 8.0 100.0)) )
         (setq b1 (/ (- br ts) 2.0) alph (atan (/ 5.0 100.0)) )
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts ho br)
       (cond
         ((= pr:efp_w "SM") (setq pts (polar pts 0 ym)))
         ((= pr:efp_w "SW") (setq pts pts))
         ('T
           (setq pts (polar pts pi (- (/ br 2.0) ez)))
         )
       );cond   

       (setq pt00 (polar pts pi ez)
             pt0  (polar pt00 0 ts)
             ptm  (polar pts pi ym)
             pt1  (polar pt0 pih (/ h-2c 2.0))
             pt16 (polar pt0 (* 3 pih) (/ h-2c 2.0))
             pt8  (polar pt00 pih (/ ho 2.0))
             pt9  (polar pt00 (* 3 pih) (/ ho 2.0))
             pt7  (polar pt8 0 br)  
             pt10 (polar pt9 0 br)  
             ptt1 (polar pt7 pi b1)
             ptt2 (polar ptt1 (* 3 pih) tg)
             pt2  (inters pt0 pt1 ptt2 (polar ptt2 alph 1) nil)
             pt5  (inters pt2 ptt2 pt7 (polar pt7 (* 3 pih) 1) nil)
             ptr1 (polar pt1 0 r1)
             pt3  (polar ptr1 (+ pih alph) r1)
             pt_7 (polar pt7 pi r2)
             pt_t (polar ptt2 (+ pih alph) r2)  
             ptr22 (inters pt_7 (polar pt_7 (* 3 pih) 1) pt_t (polar pt_t alph 1) nil)
             pt4  (polar ptr22 (+ (* 3 pih) alph) r2)
             pt6  (polar ptr22 0 r2)

             ptt1 (polar pt10 pi b1)
             ptt2 (polar ptt1 pih tg)
             pt15 (inters pt0 pt1 ptt2 (polar ptt2 (- pi alph) 1) nil)
             pt12 (inters pt15 ptt2 pt10 (polar pt10 pih 1) nil)
             ptr1 (polar pt16 0 r1)
             pt14 (polar ptr1 (- (* 3 pih) alph) r1)
             pt_7 (polar pt10 pi r2)
             pt_t (polar ptt2 (- (* 3 pih) alph) r2)  
             ptr2 (inters pt_7 (polar pt_7 pih 1) pt_t (polar pt_t (- pi alph) 1) nil)
             pt13 (polar ptr2 (- pih alph) r2)
             pt11 (polar ptr2 0 r2)

             pta1 (polar ptm  pi (* 0.1 br))
             pta2 (polar pt00 0 (* 1.1 br))
             pta3 (polar pts  pih (* 0.6 ho))
             pta4 (polar pts (* 3 pih) (* 0.6 ho)) 
       )
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt16 pt1 "_arc" pt3 "_line" pt4 "_arc" pt6 
                              "_line" pt7 pt8 pt9 pt10 pt11 "_arc" pt13 
                              "_line" pt14 "_arc" pt16 
                              "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
           (command "_.pline" pt2 pt5 pt7 pt8 pt9 pt10 pt12 pt15 "_close")
         );exakt
         ((= pr:darst "grob")
           (command "_.pline" pt7 pt8 pt9 pt10 "")
         );grob
       )
    );U
;;Hohl-profil rechteckig
;(HQU70x4 70 70 4)
;(HQU70x4 70 70 4 1 2)
;(profil a b stegdicke fr1 fr2)
;radiusInnen=fr1*t radiusAussen=fr2*t
    ((or (= typ3 "HQU") (= typ3 "HRE"))
       (setq ho (* (atof (nth 1 wert)) pr:ei_w)  ;hoehe
             br (* (atof (nth 2 wert)) pr:ei_w)  ;breite
             tt (* (atof (nth 3 wert)) pr:ei_w)  ;steg/gurt/dicke
             fr1 (atof (nth 4 wert))             ;radiusFaktorInnen
             r1 (* tt fr1)                        ;radiusInnen
             fr2 (atof (nth 5 wert))             ;radiusFAktorAussen
             r2 (* tt fr2)                        ;radiusAussen
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts ho br)
       (setq ho1 (- ho r2 r2)  
             br1 (- br r2 r2)  

             ptm pts
             pt0  (polar pts 0 (/ br 2.0))
             pt1  (polar pt0 pih (/ ho1 2.0))
             pt2  (polar pt1 pih r2)
             pt3  (polar pt2 pi r2)
             pt4  (polar pt3 pi br1)
             pt5  (polar pt4 pi r2)
             pt6  (polar pt5 (* 3 pih) r2)
             pt7  (polar pt6 (* 3 pih) ho1)
             pt8  (polar pt7 (* 3 pih) r2)
             pt9  (polar pt8 0 r2)
             pt10 (polar pt9 0 br1)
             pt11 (polar pt10 0 r2)
             pt12 (polar pt11 pih r2)

             ho1 (- ho tt tt r1 r1)  
             br1 (- br tt tt r1 r1)  
             pt00  (polar pts 0 (- (/ br 2.0) tt))
             pt01  (polar pt00 pih (/ ho1 2.0))
             pt02  (polar pt01 pih r1)
             pt03  (polar pt02 pi r1)
             pt04  (polar pt03 pi br1)
             pt05  (polar pt04 pi r1)
             pt06  (polar pt05 (* 3 pih) r1)
             pt07  (polar pt06 (* 3 pih) ho1)
             pt08  (polar pt07 (* 3 pih) r1)
             pt09  (polar pt08 0 r1)
             pt010 (polar pt09 0 br1)
             pt011 (polar pt010 0 r1)
             pt012 (polar pt011 pih r1)

             pta1 (polar pts  pi (* 0.6 br))
             pta2 (polar pts 0 (* 0.6 br))
             pta3 (polar pts  pih (* 0.6 ho))
             pta4 (polar pts (* 3 pih) (* 0.6 ho)) 

       );setq            
       (cond 
         ((= pr:darst "exakt") 
           (command "_.pline" pt12 pt1 "_arc" pt3 "_line" pt4 "_arc" pt6
                              "_line" pt7 "_arc" pt9 "_line" pt10
                              "_arc" pt12 "_close"
           )      
           (setq lastob1 (entlast)) 
           (command "_.pline" pt012 pt01 "_arc" pt03 "_line" pt04 "_arc" pt06
                              "_line" pt07 "_arc" pt09 "_line" pt010
                              "_arc" pt012 "_close"
           )      
         );exakt
         ((= pr:darst "einfach") 
           (command "_.pline" pt11 pt2 pt5 pt8 "_close")      
           (setq lastob1 (entlast)) 
           (command "_.pline" pt011 pt02 pt05 pt08 "_close")      
         );einfach
         ((= pr:darst "grob")
           (command "_.pline" pt11 pt2 pt5 pt8 "_close")      
         );grob
       )

    );H

;;Hohl-profil rund
;(HRU108 108 6.3)
    ((= typ3 "HRU")
       (setq du (* (atof (nth 1 wert)) pr:ei_w)  ;hoehe
             tt (* (atof (nth 2 wert)) pr:ei_w)  ;steg/gurt/dicke
       )

;einfuegepunkt bestimmen
       (pr_einfpkt_sym pts du du)

       (setq du1 (- du tt tt)
             pta1 (polar pts  pi (* 0.6 du))
             pta2 (polar pts 0 (* 0.6 du))
             pta3 (polar pts  pih (* 0.6 du))
             pta4 (polar pts (* 3 pih) (* 0.6 du)) 

       );setq            
       (cond 
         ((= pr:darst "exakt") 
           (command "_.circle" pts "_d" du)
           (setq lastob1 (entlast)) 
           (command "_.circle" pts "_d" du1)
         );exakt
         ((= pr:darst "einfach") 
           (command "_.circle" pts "_d" du)
           (setq lastob1 (entlast)) 
           (command "_.circle" pts "_d" du1)
         );exakt
         ((= pr:darst "grob")
           (command "_.circle" pts "_d" du)
         );grob
       )
    );HRU

  );cond end typen

;;set last objekt
  (setq lastob (entlast))
;;schraff
  (if (and (= pr:schr "1") (/= pr:darst "grob"))
    (progn
      (command "_.layer" "_ma" pr:la_schr "")
      (cond
        ((and (/= pr:schr_stil "SOLID") (and (/= typ3 "HRE")(/= typ3 "HRU")(/= typ3 "HQU")))
;kein solid kein holprofil
          (command "_.hatch" 
               (if pr:schr_stil pr:schr_stil "ansi31")
               (if pr:schr_mst  pr:schr_mst  "")
               (if pr:schr_wink pr:schr_wink "")
               lastob ""
          )
        );
        ((and (= pr:schr_stil "SOLID") (and (/= typ3 "HRE")(/= typ3 "HRU")(/= typ3 "HQU")))    
;solid kein hohlprofil
          (command "_.hatch" pr:schr_stil lastob "")
        );  
        ((and (/= pr:schr_stil "SOLID") (or (= typ3 "HRE")(= typ3 "HRU")(= typ3 "HQU")))
;kein solid holprofil
          (command "_.hatch" 
               (if pr:schr_stil pr:schr_stil "ansi31")
               (if pr:schr_mst  pr:schr_mst  "")
               (if pr:schr_wink pr:schr_wink "")
               lastob lastob1 ""
          )
        );
        ((and (= pr:schr_stil "SOLID")(or (= typ3 "HRE")(= typ3 "HRU")(= typ3 "HQU")))
;solid hohlprofil
          (command "_.hatch" pr:schr_stil lastob lastob1 "")
        );  
        ('T (prompt "UNGLTIG"))   
      );cond
      (prompt (strcat "\n" (nth 2 pr:txt)))
    );progn
  );if shraff
;;hohlprofile typ=H
;;pline/line/solid
  (command "_.layer" "_ma" pr:la_prof "")
  (cond
    ((= pr:entity "poly")(prompt (strcat "\n" typt " " (nth 3 pr:txt))))
    ((= pr:entity "line")
;      (if lastobj (command "_.explode" lastob ""))
;      (if lastobj1 (command "_.explode" lastob1 ""))
      (prompt (strcat "\n" typt " " (nth 13 pr:txt) ))
    );line
    ((= pr:entity "solid")

      (if (wcmatch (getvar "acadver") "*12*")
        (alert (nth 4 pr:txt))
        (if (= pr:laen 0.0)
          (if (= typ "H")
;;hohlprofile typ=H
            (progn
              (command "_.region" lastob "")
              (setq lastobj (entlast))
              (command "_.region" lastob1 "")
              (setq lastobj1 (entlast))
              (command "_subtract" lastobj1 "" lastobj "")
              (prompt (strcat "\n" typt " " (nth 5 pr:txt)))
            ) 
            (progn
              (command "_.region" lastob "")
              (prompt (strcat "\n" typt " " (nth 5 pr:txt) ))
            )
          );if region
          (if (= typ "H")
;;hohlprofile typ=H
            (progn
              (command "_.extrude" lastob "" pr:laen "")
              (setq lastobj (entlast))
              (command "_.extrude" lastob1 "" pr:laen "")
              (setq lastobj1 (entlast))
              (command "_subtract" lastobj1 "" lastobj "")
              (prompt (strcat "\n" typt " " (nth 6 pr:txt)))
            ) 
            (progn
            (command "_.extrude" lastob "" pr:laen "")
            (prompt (strcat "\n" typt " " (nth 6 pr:txt)))
            )
          );if solid
        );if region/solid 
      );if
    );cond solid

  );cond end

;;achsen
  (if (= pr:achs "1")
    (command "_.layer" "_ma" pr:la_achs ""
             "_.line" pta1 pta2 ""
             "_.line" pta3 pta4 "" 
    )
  )
;;schwerpunkt
  (if (= pr:spkt "1")
    (progn
      (if (= (getvar "pdmode") 0)(setvar "pdmode" 3)) 
      (command "_.layer" "_ma" pr:la_achs ""
               "_.point" pts
      )
    )
  )
;;schubmittelpunkt
  (if (= pr:mpkt "1")
    (progn
      (if (= (getvar "pdmode") 0)(setvar "pdmode" 3)) 
      (command "_.layer" "_ma" pr:la_achs ""
               "_.point" ptm
      )
    )
  )
;;block erstellen APF_profil
  (if (= pr:blk "1")
    (progn
;;auswahlsatz bilden
      (command "_.layer" "_ma" pr:la_prof "")
      (setq du entity-list entity-list (ssadd))
      (while (setq du (entnext du))
        (ssadd du entity-list)
      );while
      (setq blname (strcat "APF_" (strcase typt)))
      (if (tblsearch "block" blname)
        (progn 
          (command "_.block" blname "_y" pts entity-list "")
          (prompt (strcat "\nBlock " blname " " (nth 7 pr:txt)))
        ) 
        (progn 
          (command "_.block" blname pts entity-list "")
          (prompt (strcat "\n" typt " " (nth 8 pr:txt) blname " " (nth 9 tr:txt))) 
        )
      );if
      (command "_.insert" blname pts "" "" "")
    );progn
  ) 


);defun
;;--------------------------------------------------------
;; ERROR.LSP  error handling 
;;            save and resrtore variables 
;;--------------------------------------------------------
;; fehlerroutine small
;; pf 0693 ver 12c1/0.1
;; pf 0695 ver 12/13/0.2 liste
;; pf 0695 ver 12/13/0.3 undo beginn/end
;;--------------------------------------------------------
(defun pr:error (msg)
  (if (/= msg "Function cancelled" )
    (prompt (strcat "\nAPF_Fehler:  " msg))
    (prompt (strcat "\nAPF_Fehler:  " (nth 10 pr:txt)) )
  ) 
  (setq *error* apf_v:oerror)
  (pr:error_r)
  (princ)
)
;
; save
;
; apf_f:error_s (list "cmdecho" "blipmode"))
; apf_f:error_s (nil)
;
(defun pr:error_s (liste) 

 (setq apf_v:oerrl nil
       apf_v:olay (getvar "clayer")
       ocmd (getvar "cmdecho") 
 )
 (setvar "cmdecho" 0)
 (command "_.undo" "_be") 
 (if (tblsearch "UCS" "APF_UCS") (command "_.ucs" "_del" "apf_ucs"))
 (command "_.ucs" "_save" "apf_ucs")

 (repeat (length liste)
   (setq du (car liste)
         apf_v:oerrl 
           (cons 
             (list du (getvar du)) 
             apf_v:oerrl
           )
         liste (cdr liste)
   )
 )
 (setq apf_v:oerror *error* 
       *error* pr:error
 )

)
;
; restore
;
(defun pr:error_r (/ lis var val)

  (setvar "clayer" apf_v:olay) 
  (repeat (length apf_v:oerrl)
    (setq lis (car apf_v:oerrl)
          var (car lis)
          val (cadr lis)
          apf_v:oerrl (cdr apf_v:oerrl)
    )
    (setvar var val)
  )
  (setq *error* apf_v:oerror)
  (setvar "cmdecho" 0) 
  (command "_.ucs" "_restore" "apf_ucs")
  (command "_.ucs" "_del" "apf_ucs")
  (command "_.undo" "_e") 
  (setvar "cmdecho" ocmd)
  (princ)

)

(princ (strcat "\n" (nth 11 pr:txt) "  " pr:rel)) 
(princ)

