;;;CADALYST 05/05 Tip 2031: SBOX.lsp  	Draw a shadow box 	(c) 2005 JefferyPSanders.com



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;; Function to save the dialog box settings  ;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defun saveVars()
  (setq sBoxLt(distof(get_tile "sboxlt")))
  (setq sBoxSt(distof(get_tile "sboxst")))
  (setq sBoxRad1(atoi(get_tile "rad1")))
  (setq sBoxRad2(atoi(get_tile "rad2")))
  (setq sBoxRad3(atoi(get_tile "rad3")))
  (setq sBoxRad4(atoi(get_tile "rad4")))

  ;;;--- Set the defaults for next use
  (setvar "userr1" sBoxLt)
  (setvar "userr2" sBoxSt)
  (setvar "useri1" sBoxRad1)
  (setvar "useri2" sBoxRad2)
  (setvar "useri3" sBoxRad3)
  (setvar "useri4" sBoxRad4)
)

;;;;;;;;;;;;;;;;;;;;;;; End of saving settings from dialog box ;;;;;;;;;;;;;;;;;;;;;




;;;;;;;;;;;;;;;;;;;;; Function to get data from text objects ;;;;;;;;;;;;;;;;;;;;;;;

(defun getDataFromText()

  ;;;--- Let the user select the text objects
  (if(setq eset(ssget))
    (progn

      ;;;--- Set up a counter and some minimums/maximums
      (setq cntr 0 xmin nil xmax nil ymin nil ymax nil)

      ;;;--- Cycle through the selection set
      (while(< cntr (sslength eset))

        ;;;--- Get the entity name of the nth entity
        (setq en(ssname eset cntr))

        ;;;--- Get the DXF group codes of the entity
        (setq enlist(entget en))

        ;;;--- Get the entity type
        (setq entType(cdr(assoc 0 enlist)))

        ;;;--- Do a conditional loop
        (cond
          (
            ;;;--- If the entity type is TEXT...
            (= entType "TEXT")
            (progn

              ;;;--- Get the text height
              (setq txtHt(cdr(assoc 40 enlist)))

              ;;;--- If this is the first round, get the x,y minimums/maximums
              (if(< cntr 1)
                (progn

                  ;;;--- The x and y minimums are the insertion point of the text
                  (setq x(car (cdr(assoc 10 enlist))))
                  (setq y(cadr(cdr(assoc 10 enlist))))
                  (setq xmin x)
                  (setq ymin y)

                  ;;;--- The x and y maximums are found by using the textbox function
                  (setq xmax(+ x (car (cadr(textbox enlist)))))
                  (setq ymax(+ y (cadr(cadr(textbox enlist)))))
                )

                ;;;--- Else this is not the first round, so see if this text exceeds the minimums/maximums
                (progn

                  ;;;--- The x and y minimums are found in the text insertion point
                  (setq x(car (cdr(assoc 10 enlist))))
                  (setq y(cadr(cdr(assoc 10 enlist))))

                  ;;;--- If they are less than the previous minimums, set them as the new minimums                
                  (if(< x xmin)(setq xmin x))
                  (if(< y ymin)(setq ymin y))

                  ;;;--- Calculate the current text entity's x and y using textbox and set them if they are bigger
                  (if(> (+ x (car (cadr(textbox enlist)))) xmax)(setq xmax(+ x (car (cadr(textbox enlist))))))
                  (if(> (+ y (cadr(cadr(textbox enlist)))) ymax)(setq ymax(+ y (cadr(cadr(textbox enlist))))))
                )
              )
            )
          )
          (

            ;;;--- Else if the text entity is an MTEXT type of entity
            (= entType "MTEXT")
            (progn

              ;;;--- Get the text height
              (setq txtHt(cdr(assoc 40 enlist)))

              ;;;--- Get the mtext insertion location code
              (setq insPt(cdr(assoc 71 enlist)))

              ;;;--- Get the insertion point
              (setq ipt(cdr(assoc 10 enlist)))
             
              ;;;--- Get the x and y coords of the insertion point
              (setq xc(car ipt))
              (setq yc(cadr ipt))

              ;;;--- Get the width of the text area
              (setq rw(cdr(assoc 42 enlist)))

              ;;;--- Get the height of the text area
              (setq rh(cdr(assoc 43 enlist)))
             
              ;;;--- Enter another conditional loop to check for the mtext insertion location
              (cond

                ;;;--- MPT1 = Bottom left of rectangle
                ;;;--- MPT2 = Top right of rectangle

                ;;;--- If the insertion point is TOP-LEFT...
                ((= insPt 1)(setq mtPt1(list xc (- yc rh)) mtPt2(list (+ xc rw) yc)))

                ;;;--- If the insertion point is TOP-CENTER...
                ((= insPt 2)(setq mtPt1(list (- xc (/ rw 2.0)) (- yc rh)) mtPt2(list (+ xc (/ rw 2.0)) yc)))

                ;;;--- If the insertion point is TOP-RIGHT...
                ((= insPt 3)(setq mtPt1(list (- xc rw) (- yc rh)) mtPt2(list xc yc)))

                ;;;--- If the insertion point is MID-LEFT...
                ((= insPt 4)(setq mtPt1(list xc (- yc (/ rh 2.0))) mtPt2(list (+ xc rw) (+ yc (/ rh 2.0)))))

                ;;;--- If the insertion point is MID-CENTER...
                ((= insPt 5)(setq mtPt1(list (- xc (/ rw 2.0)) (- yc (/ rh 2.0))) mtPt2(list (+ xc (/ rw 2.0)) (+ yc (/ rh 2.0)))))

                ;;;--- If the insertion point is MID-RIGHT...
                ((= insPt 6)(setq mtPt1(list (- xc rw) (- yc (/ rh 2.0))) mtPt2(list xc (+ yc (/ rh 2.0)))))

                ;;;--- If the insertion point is BOTTOM-LEFT...
                ((= insPt 7)(setq mtPt1(list xc yc) mtPt2(list (+ xc rw) (+ yc rh))))

                ;;;--- If the insertion point is BOTTOM-CENTER...
                ((= insPt 8)(setq mtPt1(list (- xc (/ rw 2.0)) yc) mtPt2(list (+ xc (/ rw 2.0)) (+ yc rh))))

                ;;;--- If the insertion point is BOTTOM-RIGHT...
                ((= insPt 9)(setq mtPt1(list (- xc rw) yc) mtPt2(list xc (+ yc rh))))
              )

              ;;;--- If this is the first loop, grab some default minimums and maximums            
              (if(< cntr 1)
                (progn
                  (setq xmin (car  mtPt1))
                  (setq ymin (cadr mtPt1))
                  (setq xmax (car  mtPt2))
                  (setq ymax (cadr mtPt2))
                )

                ;;;--- Else, find out if this mtext entity exceeds the minimums and maximums of the previous entities
                (progn
                  (if(and xmin xmax ymin ymax)
                    (progn
                      (if(< (car  mtPt1) xmin)(setq xmin (car  mtPt1)))
                      (if(< (cadr mtPt1) ymin)(setq ymin (cadr mtPt1)))
                      (if(> (car  mtPt2) xmax)(setq xmax (car  mtpt2)))
                      (if(> (cadr mtPt2) ymax)(setq ymax (cadr mtpt2)))
                    )
                  )
                )
              )
            )
          )
        )

        ;;;--- Increment the counter to get the next entity
        (setq cntr(+ cntr 1))
      )  

      ;;;--- If minimums and maximums were found
      (if (and xmin xmax ymin ymax)
        (progn

          ;;;--- Add a gap around the text equal to one text height and find each corner
          (setq blpt (list (- xmin txtHt) (- ymin txtHt)))
          (setq tlpt (list (- xmin txtHt) (+ ymax txtHt)))
          (setq trpt (list (+ xmax txtHt) (+ ymax txtHt)))
          (setq brpt (list (+ xmax txtHt) (- ymin txtHt)))
        )

        ;;;--- Else set all of the corner points to nil
        (setq blpt nil tlpt nil trpt nil brpt nil)
      )
    ) 
  )
)                   
  

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                          ;;;
;;;     888       888          888           8888888      8888   888         ;;;
;;;     8888     8888         88888            888        88888  888         ;;;
;;;     88888   88888        888 888           888        888888 888         ;;;
;;;     888888 888888       888   888          888        888 888888         ;;;
;;;     888 88888 888      88888888888         888        888  88888         ;;;
;;;     888  888  888     888       888      8888888      888   8888         ;;;
;;;                                                                          ;;;
;;;                                                                          ;;;
;;;                888            888888888        888888888                 ;;;
;;;               88888           888   888        888   888                 ;;;
;;;              888 888          888   888        888   888                 ;;;
;;;             888   888         888888888        888888888                 ;;;
;;;            88888888888        888              888                       ;;;
;;;           888       888       888              888                       ;;;
;;;                                                                          ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defun C:SBOX(/ blpt tlpt trpt brpt)

  ;;;--- Turn the command echo off
  (setvar "cmdecho" 0)

  ;;;--- Save the osnap settings
  (setq oldOsmode(getvar "osmode"))

  ;;;--- Turn osnaps off
  (setvar  "osmode" 0)

  ;;;--- Preset an exit string
  (setq alertStr "\n  SBOX.lsp naten!")

  ;;;--- Put up the dialog box
  (setq dcl_id (load_dialog "SBOX.dcl"))

  ;;;--- See if it is already loaded
  (if (not (new_dialog "SBOX" dcl_id))
    (progn
      (alert "DCL soubor SBOX.dcl nebylo mon nalzt!")
      (exit)
    )
  )

  ;;;--- Get the defaults if they exist
  (if(> (getvar "userr2") 0.0)
    (progn
      (set_tile "sboxlt" (rtos (getvar "userr1")))
      (set_tile "sboxst" (rtos (getvar "userr2")))  
      (set_tile "rad1" (itoa(getvar "useri1")))
      (set_tile "rad2" (itoa(getvar "useri2")))
      (set_tile "rad3" (itoa(getvar "useri3")))
      (set_tile "rad4" (itoa(getvar "useri4")))
    )

    ;;;--- Else simply multiply the default shadow width by the dimscale
    (set_tile "sboxst" (rtos (* (getvar "dimscale") 0.125)))      
  )
    

  ;;;--- If an action event occurs, do this function
  (action_tile "cancel"  "(setq ddiag 1)(done_dialog)")
  (action_tile "getdata" "(setq ddiag 2)(saveVars)(done_dialog)")
  (action_tile "accept"  "(setq ddiag 3)(saveVars)(done_dialog)") 

  ;;;--- Display the dialog box
  (start_dialog)

  ;;;--- Unload the dialog box from memory
  (unload_dialog dcl_id)

  ;;;--- If the cancel button was pressed
  (if (= ddiag 1)

    ;;;--- Set an exit message
    (setq alertStr "\n \n. SBOX stornovn. \n ")
  )

  ;;;--- If the create from text button was pressed
  (if (= ddiag 2)
    (progn

      ;;;--- Get the rectangle for the shadow box from the text or mtext entities
      (getDataFromText)

      ;;;--- If the corners were found...
      (if(and blpt trpt brpt tlpt)

        ;;;--- Set ddiag to 3 to enter the drawing phase
        (setq ddiag 3)  

        ;;;--- Else display an alert
        (setq alertStr "\n \n. Nebyly vybrny dn objekty! \n ")
      )
    )
  )

  
  ;;;--- If the "Okay" button was pressed
  (if (= ddiag 3)
    (progn

      ;;;--- If a rectangle is not defined, the user wants to draw it
      (if(and(not blpt)(not brpt)(not tlpt)(not trpt))
        (progn

          ;;;--- Get the corners for the shadow box
          (setq fCrnr(getpoint "\n Prvn roh: "))
          (setq oCrnr(getcorner fCrnr "\n Druh roh: "))

          ;;;--- Find out which corner is lower left and upper right
          ;;;    fCrner = Lower left     oCrnr = Top right
          (if(< (car fCrnr)(car oCrnr))
            (setq blpt fCrnr trpt oCrnr)
            (setq blpt oCrnr trpt fCrnr)
          )
        )
      )

      ;;;--- Find the shadow box height and width
      (setq sBoxHt (- (cadr trpt)(cadr blpt)))
      (setq sBoxWd (- (car trpt)(car blpt)))
      
      ;;;--- Find the shadow box corners
      (setq tlpt(polar blpt (* pi 0.5) sBoxHt))
      (setq brpt(polar blpt 0 sBoxWd))
    
      ;;;--- Find the shadow points
      (setq ptList(list))
      (cond
        (
          (= sBoxRad1 1)      ;;;--- Down and right
          (progn

            ;;;--- Reset the shadow box corners based on thickness
            (setq trpt(polar trpt 0 (/ sBoxLt 2.0)))

            ;;;--- ptList is a list containing list of two items,
            ;;;    A control string and a point.
            ;;;
            ;;;    Control String - 
            ;;;                      "N" means no change in width or direction
            ;;;                      "I" means increase polyline width
            ;;;                      "D" means decrease polyline width
            ;;;                      "*U" means up
            ;;;                      "*D" means down
            ;;;                      "*L" means left
            ;;;                      "*R" means right
            ;;;
            ;;;                      "ID" means increase polyline width in a downward direction
            ;;;                      "DR" means decrease polyline width towards the right

            ;;;--- Build the ptList
            (setq ptList
              (list
                (list "N" blpt)
                (list "N" tlpt)
                (list "N" trpt)
                (list "N" (setq pt1(polar trpt (* pi 1.5) sBoxSt)))
                (list "IR" pt1)
                (list "N" (setq pt3(polar(polar brpt 0 (/ sBoxSt 2.0)) (* pi 1.5) (/ sBoxSt 2.0))))
                (list "N" (setq pt2(polar pt3 pi (- sBoxWd (/ sBoxSt 2.0)))))
                (list "DU" pt2)
                (list "N" (polar (polar blpt pi (/ sBoxLt 2.0)) (* pi 1.5) (/ sBoxLt 2.0)))
              )         
            )
          )
        )

        (
          (= sBoxRad2 1)      ;;;--- Down and left
          (progn

            (setq ptList
              (list
                (list "IL" blpt)
                (setq blpt(polar blpt pi (- (/ sBoxSt 2.0)(/ sBoxLt 2.0))))
                (list "N" (setq pt1(polar blpt (* pi 0.5) (- sBoxHt sBoxSt))))
                (list "DR" pt1)
                (list "N" tlpt)
                (list "N" trpt)
                (list "N" brpt)
                (list "N" (setq pt2(polar brpt pi sBoxSt)))
                (list "ID" pt2)
                (list "N" (polar (polar blpt pi (/ sBoxSt 2.0)) (* pi 1.5)(- (/ sBoxSt 2.0)(/ sBoxLt 2.0)) ))
              )         
            )        

          )
        )

        (
          (= sBoxRad3 1)      ;;;--- Up and right
          (progn

            ;;;--- Reset the corners based on thickness
           (setq trpt(polar (polar trpt (* pi 0.5) (- (/ sBoxSt 2.0) (/ sBoxLt 2.0))) 0 (/ sBoxSt 2.0)))
           (setq brpt(polar brpt 0 (/ sBoxLt 2.0)))

            (setq ptList
              (list
                (list "N" blpt)
                (list "N" tlpt)
                (list "N" (setq pt1(polar tlpt 0 sBoxSt)))
                (list "IU" pt1)
                (list "N" trpt)
                (list "N" (setq pt2(polar trpt (* pi 1.5) (- sBoxHt sBoxSt))))
                (list "DL" pt2)
                (list "N" brpt)
                (list "N" (polar blpt pi (/ sBoxLt 2.0)))
              )         
            )        
        

          )
        )

        (
          (= sBoxRad4 1)      ;;;--- Up and left
          (progn
        
           ;;;--- Reset the corners based on thickness
           (setq tlpt(polar (polar tlpt (* pi 0.5) (- (/ sBoxSt 2.0) (/ sBoxLt 2.0))) pi(- (/ sBoxSt 2.0) (/ sBoxLt 2.0))))

            (setq ptList
              (list
                (list "N" blpt)
                (list "N" (setq pt1(polar blpt (* pi 0.5) sBoxSt)))
                (list "IL" pt1)
                (list "N" tlpt)
                (list "N" (setq pt2(polar tlpt 0 (+ (- sBoxWd sBoxSt) (/ sBoxLt 2.0)))))
                (list "DD" pt2)
                (list "N" trpt)
                (list "N" brpt)
                (list "N" (polar blpt pi (/ sBoxLt 2.0)))
              )         
            )        
          )
        )
      )

      ;;;--- If ptList was built......
      (if ptList
        (progn

          ;;;--- Get half of the shadow box shadow thickness  h = half  St = Shadow Thickness
          (setq hsBoxSt(/ sBoxSt 2.0))

          ;;;--- Get half of the shadow box line thickness  h = half  Lt = Line Thickness         
          (setq hsBoxLt(/ sBoxLt 2.0))

          ;;;--- Start the pline command at the lower left point and set the thickness to line thickness
          (command "_pline" (cadr (car ptList)) "_w" sBoxLt sBoxLt)

          ;;;--- Cycle through each point in the ptList
          (foreach a ptList

            ;;;--- Get the control string
            (setq ctrlChar(car a))

            ;;;--- Get the point
            (setq ctrlPt(cadr a))

            ;;;--- Conditional loop based on the control string
            (cond
           
              ;;;--- If no change is required, simply send the point to the pline command
              ((= ctrlChar "N")(command ctrlPt))

              ;;;--- Increase polyline thickness to the right
              ((= ctrlChar "IR")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt 0  (- hsBoxSt hsBoxLt))) "_w" sBoxSt sBoxSt))

              ;;;--- Increase polyline thickness to the left
              ((= ctrlChar "IL")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt pi (- hsBoxSt hsBoxLt))) "_w" sBoxSt sBoxSt))

              ;;;--- Decrease polyline thickness towards the right
              ((= ctrlChar "DR")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt 0  (- hsBoxSt hsBoxLt))) "_w" sBoxLt sBoxLt))

              ;;;--- Decrease polyline thickness towards the left
              ((= ctrlChar "DL")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt pi (- hsBoxSt hsBoxLt))) "_w" sBoxLt sBoxLt))

              ;;;--- Increase polyline thickness downward
              ((= ctrlChar "ID")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt (* pi 1.5) (- hsBoxSt hsBoxLt))) "_w" sBoxSt sBoxSt))

              ;;;--- Increase polyline thickness upward
              ((= ctrlChar "IU")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt (* pi 0.5) (- hsBoxSt hsBoxLt))) "_w" sBoxSt sBoxSt))

              ;;;--- Decrease polyline thickness upward
              ((= ctrlChar "DU")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt (* pi 0.5) (- hsBoxSt hsBoxLt))) "_w" sBoxLt sBoxLt))

              ;;;--- Decrease polyline thickness downward
              ((= ctrlChar "DD")(command "_w" 0 0 (setq ctrlPt(polar ctrlPt (* pi 1.5) (- hsBoxSt hsBoxLt))) "_w" sBoxLt sBoxLt))
            )
          )

          ;;;--- Finishe the pline command
          (command)
        )
      )
    )
  )

  (princ (strcat "\n.\n.\n. Copyright 2005 by JefferyPSanders.com" alertStr))

  ;;;--- Reset the osnaps
  (setvar "osmode" oldOsmode)

  ;;;--- Reset the command echo
  (setvar "cmdecho" 1)

  ;;;--- Suppress the last echo
  (princ)
)
