;=========================================================================
; CHOP.lsp    (Command function for AutoCAD) 
; (c) Copyright 2001 TimeSavers for CAD
; from: www.timesaversforcad.com
;-------------------------------------------------------------------------
; Description:
;
; Quickly TRIMs or EXTENDs objects by first drawing cut/extend line
; then a "fence" line across entities to be trimmed or extended.
;
; Command option: "W"indow - will TRIM objects within a window
; specified by 2 points.
;=========================================================================
(defun c:chop (/ *chp:err* c_e o_m x y el p1 p2 p3 p4 ang13 ang24 f1
								 cmnd plst clr grv vsf rp_t)
  ;-ERROR HANDLING
  (defun *chp:err* (m)
    (or (member m '("Funkce zruena" "_quit / _exit _abort" "console break"))
        (prompt (strcat "\n< " m " >\n"))
    )
    (and el (entdel el)(setq el nil))
    (if grv (grvecs (list -256 p2 p3)))
    (if o_m (setvar "osmode" o_m))(setvar "cmdecho" c_e)
    (setq *error* *e*)(princ)
  )

  ;-GET VALUES				*e* (cond (*e*)(*error*))
  (setq *error* *chp:err*
        o_m (getvar "osmode")
        c_e (getvar "cmdecho")
  )
  (setvar "cmdecho" 0)
  (setq clr 7  ;line,fence,window color
        rp_t T ;set nil to not repeat
  )

  ;-MAIN FUNCTION
  (while
    (and (or rp_t (setq x (not x)))
      (progn
        (while (not (or (initget 128 "O P")
                        (listp (setq p1 (getpoint "\nOkno/Prodlouit/<Oezat- prvn bod>: ")))
                        (= p1 "O")(= p1 "P")
                        (= (type (setq p1 (eval (read p1)))) 'LIST)
        )))
        (cond ((or (= (type p1) 'LIST)(= p1 "P")) ;--CHOP OR EXTEND W/ LINE
                (command "_undo" "_g")
                (setvar "orthomode" 1)
                (if (and (if (listp p1)
                           (setq cmnd "_TRIM")
                           (progn
                             (setq cmnd "_EXTEND")
                             (while (not (or (initget 128)
                                             (listp (setq p1 (getpoint "\nProdlouit- prvn bod: ")))
                                             (= (type (setq p1 (eval (read p1)))) 'LIST)
                             )))
                             p1
                           )
                         )
                         (setq p2 (getpoint p1 "Druh bod: "))
                         (setvar "osmode" 0)
                         (entmake (list '(0 . "LINE") '(6 . "CONTINUOUS") (cons 62 clr)
                                        (cons 10 (trans p1 1 0))(cons 11 (trans p2 1 0))
                         ))
                         (setq el (entlast))
                         (setvar "orthomode" 0)
                         (not (initget 32))
                         (setq p3 (getpoint p2 (strcat "\n" cmnd " objekty <Urete prvn roh>: ")))
                    )
                  (progn
                    (if (= cmnd "_EXTEND")
                      (progn
                        (setq grv T)
                        (grvecs (list (- 256) p2 p3)) ;draw dashed vector, >255 so erases itself next vector
                        (initget 32)
                        (setq p4 (getpoint p3 "\nProdlouit objekty <Urete prvn roh>: "))
                        (setq grv (grvecs (list (- 256) p2 p3))) ;erase vector
                      )
                    )
                    (command cmnd el "")
                    (command "_f" (polar p2 (angle p1 p3) 0.001) p3)
                    (if p4 (command p4))
                    (command "" "")
                    (entdel el)(setq el nil)
                  )
                  (and el (entdel el)(setq el nil p2 nil))
                )
                (setvar "osmode" o_m)
                (command "_undo" "_e")
                (and p1 p2)
              )
              ;-CHOP WITH WINDOW
              ((= p1 "O")
                (while (and (or rp_t (setq y (not y)))
                            (setq p1 (getpoint "\nPrvn roh: "))
                            (setq p3 (getcorner p1 "\nDruh roh: "))
                       )
                  (setq p2 (list (car p1) (cadr p3))
                        p4 (list (car p3) (cadr p1))
                        ang13 (angle p1 p3)
                        ang24 (angle p2 p4)
                        plst (list p1 p2 p3 p4)
                  )
                  (command "_undo" "_g")
                  (setvar "osmode" 0)
                  (entmake (list '(0 . "POLYLINE")(cons 62 clr)'(70 . 1)'(66 . 1)))
                  (foreach n plst (entmake (list '(0 . "VERTEX") (cons 62 clr) (cons 10 (trans n 1 0)))))
                  (entmake (list '(0 . "SEQEND")(cons 62 clr)))
                  (setq el (entlast) vsf (/ (getvar "viewsize") 500.0))
                  (command "_trim" el "" "_f"
                    (setq f1 (polar p1 ang13 vsf))
                    (polar p2 ang24 vsf)
                    (polar p3 (+ pi ang13) vsf)
                    (polar p4 (+ pi ang24) vsf)
                    f1 "" ""
                  )
                  (entdel el)(setq el nil)
                  (setvar "osmode" o_m)
                  (command "_undo" "_e")
                  (if (setq p1 (nentselp p1))(entupd (car p1)))
                )
              )
        )
      )
    )
  )

  ;-RETURN VARIABLES
  (setvar "osmode" o_m)
  (setvar "cmdecho" c_e)
  (setq *error* *e*)
  (princ)
)
;-END FILE
