;;;
;;;  HEAL.LSP   Version 1.0
;;;
;;;  Copyright (C) 1996 by Jay Garnett
;;;
;;;  Permission to use, copy, modify, and distribute this software
;;;  for any purpose and without fee is hereby granted, provided
;;;  that the above copyright notice appears in all copies and
;;;  that both that copyright notice and the limited warranty 
;;;  below appear in all supporting documentation.
;;;
;;;  JAY GARNETT PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
;;;  JAY GARNETT SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
;;;  MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE. JAY GARNETT
;;;  DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
;;;  UNINTERRUPTED OR ERROR FREE.
;;;
;;;  DESCRIPTION
;;;  Works like the opposite of the break command. Pick two lines and they become one.
;;;  The properties of the new line are the same as the FIRST line selected. This routine
;;;  Was intended to correct a situation like the one shown below.
;;;
;;;             First Line               Break           Second Line
;;;  --------------------------------------X-----------------------------------
;;;  
;;;  It will attempt to heal any two lines selected, even if they are not near each other.
;;;
;;;  By Jay Garnett
;;;  Bolingbrook, IL
;;;  
;;;  E-Mail jgarnett@enteract.com
;;;

(defun Get_Line( / OBJ )
  (while (not OBJ)
    (setq OBJ(car(entsel "\nVyberte seku:")))
    (if (/= (cdr(assoc 0(entget OBJ))) "LINE")
     (progn (prompt "\nVybran entita nen sekou. Zkuste to znovu.")
            (setq OBJ nil)
     )
     OBJ
   )
  )
)
(defun Newerr()
   (setvar "cmdecho" CE)
   (setvar "osmode" UOS)
   (setvar "orthomode" UORTH)
   (setq *error* olderr )
   (command "._redraw")
   (princ)
)


(defun c:Heal( / ENT1 ENT2 NLINE 1PT10 2PT10 OLD10
                 1PT11 2PT11 OLD11 DIST1 DIST2 DIST3 DIST4
                 DSTLST MAXDST PT1 PT10 PT11)
   (setq olderr *error*
         *error* Newerr
         CE(getvar "cmdecho")
         UOS(getvar "osmode")
         UORTH(getvar "orthomode"))
   (setvar "cmdecho" 0)
   (setvar "osmode" 0)
   (setvar "orthomode" 1)
   (setq ENT1(Get_Line)
         ENT2 ENT1
   )
   (redraw ENT1 3)
   (while (eq ENT1 ENT2)
     (setq ENT2(Get_Line))
   )
   (setq NLINE (entget ENT1)
         1PT10(cdr(setq OLD10(assoc 10 NLINE)))
         1PT11(cdr(setq OLD11(assoc 11 NLINE)))
         PARAMS2(entget ENT2)
         2PT10(cdr(assoc 10 PARAMS2))
         2PT11(cdr(assoc 11 PARAMS2))
         DIST1(distance 1PT10 2PT10)
         DIST2(distance 1PT10 2PT11)
         DIST3(distance 1PT11 2PT10)
         DIST4(distance 1PT11 2PT11)
         DSTLST(list(list DIST1 1PT10 2PT10)(list DIST2 1PT10 2PT11)
                    (list DIST3 1PT11 2PT10)(list DIST4 1PT11 2PT11)
               )
         MAXDST(max DIST1 DIST2 DIST3 DIST4)
         PTS(cdr(assoc MAXDST DSTLST))
         PT10(car PTS)
         PT11(cadr PTS)
         NLINE(subst(cons 10 PT10) OLD10 NLINE)
         NLINE(subst(cons 11 PT11) OLD11 NLINE)
   )
   (entdel ENT2)
   (entmod NLINE)
   (entupd ENT1)
   (Newerr)
   (setq *error* olderr olderr nil)
   (princ)
)
