
;;;
;;; This program defines a command called PERLIN
;;; By using this command you can draw a line
;;; perpendicular to any specified line. The direction
;;; of the base line can also be evaluated by locating
;;; two points.
;;; The command is also applicable in 3D space.
;;;
;;; Generated by : Alireza Parsai - 21 Jan 2002
;;; AutoCAD Consultant
;;; Alkhawarizmi Institute (Abu Dhabi - UAE)
;;; email: alireza@khawarizmi.com
;;; URL: http://www.khawarizmi.com
;;; Phone: 00971 2 633 5715
;;; Mobile: 00971 50 6710227
;;;


;; A function that defines common lines of two methods
(defun commonlines (A B C / D L PLLen Alfa Beta OS)
  (setq os (getvar "osmode"))		; Get OSnap modes available
  (setvar "osmode" 0)			; Deactivate any current OSnap
  (setq L (distance A B))		; Evaluate the distance between two points or the length of the line
  (setq					; Define the length of the perpendicular line
    PLLen
     (getreal
       (strcat "\nZadejte dlku kolmice <"
	       (rtos L)
	       ">: "
       )
     )
  )
  (if (= PLLen nil)			; If no answer set the new line length equal to the base line length
    (setq PLLen L)
  )
  (setq	Alfa (angle A B)		; Extract the base line angle in radians
	Beta (+ (/ Pi 2.0) Alfa)	; Extract the perpendicular line angle in radians
	D    (polar C Beta PLLen)	; Find the endpoint of the perpendicular line
  )
  (entmake (list '(0 . "LINE") (cons 10 C) (cons 11 D)))
					; Create the perpendicular line
  (setvar "osmode" os)			; Activate the OSnap mode to its original settings
) ;_end of function: COMMONLINES

;;The function SELECTLINE is used to extract information from a selected line
(defun selectline (/ ename elist etype A B C D L PLLen Alfa Beta OS)
  (princ "\nVyberte pouze seku ...")	; A warning
  (setq ename (car (entsel)))		; Select the object
  (while (= ename nil)
    (setq ename (car (entsel)))		; Select the object
  )
  (setq	elist (entget ename)		; Get the DXF codes of the line
	etype (cdr (assoc 0 elist))	; Specify the type of selected object
  )
  (While (/= etype "LINE")		; Repeat selection until a line is selected
    (alert "Vybran objekt nen seka.")
    (princ
      "\nVyberte pouze seku ..."
    )
    (setq ename (car (entsel)))		; Select object
    (while (= ename nil)
      (setq ename (car (entsel)))	; If clicked a blank area repeat the selection
    )
    (setq
      elist (entget ename)
      etype (cdr (assoc 0 elist))
    )
  )
  (setq	A (cdr (assoc 10 elist))	; Extract the first endpoint of the line
	B (cdr (assoc 11 elist))	; Extract the second endpoint of the line
	C (getpoint			; Ask for the first enpoint of the perpendicular line
	    "\nUrete poten bod kolmice: "
	  )
  )
  (commonlines A B C)			; Start COMMONLINE function to finalize the process
) ;_end of function: SELECTLINE

;; The main body of the program defines the method of operation and if it is Two points method
;; conducts some of the opperations, else the SELECTLINE fuction will be called.
(defun c:perlin	(/ Method)
  (setvar "cmdecho" 0)			; Do not echo commands run through this program
  (command "_undo" "_be")			; The beginning of an undo group
  (setq	Method				; Ask for the method of operation
	 (getstring
	   "\nZvolte zpsob [Dva body/Vybrat seku] <Vybrat seku>: "
	 )
  )
  (if (or (= Method "") (= Method "V") (= Method "v"))
    (selectline)			; Call SELECTLINE function by user input
    (if	(or (= Method "D") (= Method "d"))
					; If Two point method is specified go for the following lines
      (progn
	(setq A	(getpoint "\nUrete prvn bod smru: ")
					; Get the first point
	      B	(getpoint A "\nUrete dal bod smru: ")
					; Get the second point
	      C	(getpoint
		  "\nUrete poten bod kolmice: "
		)			; Get the first point of the perpendicular line
	)
	(commonlines A B C)		; Finalize the process by activating COMMONLINES function
      )
      (princ "\nNeplatn vstup")	; Show this message if the correct method is not specified
    )
  )
  (command "_undo" "_end")		; The end of undo group
  (setvar "cmdecho" 1)			; Set the CMDECHO variable to its original value
  (princ)				; Clean exit
) ;_end of main body
